# Bazaar-NG -- distributed version control

# Copyright (C) 2005 by Canonical Ltd

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


def show_status(state, kind, name):
    if kind == 'directory':
        # use this even on windows?
        kind_ch = '/'
    elif kind == 'symlink':
        kind_ch = '->'
    else:
        assert kind == 'file', ("can't handle file of type %r" % kind)
        kind_ch = ''

    assert len(state) == 1
        
    print state + '       ' + name + kind_ch
    
